==> elgg-1.9.2.zip: elgg-1.9.2/mod/web_services/languages/ja.php <==
<?php
return array(
	'APIException:ApiResultUnknown' => "API Result は不明な型です。このようなことは起きないはずなのですが。。。",
	'APIException:MissingParameterInMethod' => "メソッド '%2$s' のパラメタ '%1$s' が欠落しています",
	'APIException:ParameterNotArray' => "%s は、配列ではないようです。",
	'APIException:UnrecognisedTypeCast' => "メソッド '%3$s' の変数 '%2$s' のキャスト %1$s の型がわかりません。",
	'APIException:InvalidParameter' => "メソッド '%2$s' のパラメタ '%1$s' が不適切な値でした。",
	'APIException:FunctionParseError' => "%s(%s) にはパース・エラーが１つあります。",
	'APIException:FunctionNoReturn' => "%s(%s) は値を返しませんでした。",
	'APIException:APIAuthenticationFailed' => "メソッドの呼び出しは API Aithentication に失敗しました。",
	'APIException:UserAuthenticationFailed' => "メソッドの呼び出しは User Authentication に失敗しました。",
	'APIException:MethodCallNotImplemented' => "メソッドの呼び出し '%s' は、実装されていません。",
	'APIException:FunctionDoesNotExist' => "メソッド '%s' の関数は呼び出し不可能です。",
	'APIException:AlgorithmNotSupported' => "アルゴリズム '%s' はサポートされていないか、利用不可となっています。",
	'APIException:NotGetOrPost' => "リクエストの手段は GET もしくは、 POST でないといけません。",
	'APIException:MissingAPIKey' => "API key がありません",
	'APIException:BadAPIKey' => "API key が間違っています",
	'APIException:MissingHmac' => "X-Elgg-hmac ヘッダがありません",
	'APIException:MissingHmacAlgo' => "X-Elgg-hmac-algo ヘッダがありません",
	'APIException:MissingTime' => "X-Elgg-time ヘッダがありません",
	'APIException:MissingNonce' => "X-Elgg-nonce ヘッダがありません",
	'APIException:TemporalDrift' => "X-Elgg-time があまりにも過去か未来過ぎます。エポック取得に失敗しました",
	'APIException:NoQueryString' => "クエリ文字列にデータがありません",
	'APIException:MissingPOSTHash' => "X-Elgg-posthash ヘッダがありません",
	'APIException:MissingPOSTAlgo' => "X-Elgg-posthash_algo ヘッダがありません",
	'APIException:MissingContentType' => "投稿データのコンテント型がありません",
	'SecurityException:APIAccessDenied' => "申し訳ありません。API へのアクセスは管理者によって使用不可に設定されています。",
	'SecurityException:NoAuthMethods' => "このAPIリクエストの認証を行うにあたって、担当するメソッドが見つかりませんでした。",
	'SecurityException:authenticationfailed' => "ユーザは認証できませんでした。",
	'InvalidParameterException:APIMethodOrFunctionNotSet' => "expose_method() において、メソッドあるいは関数が設定されていません",
	'InvalidParameterException:APIParametersArrayStructure' => "メソッド '%s' 呼び出しにおいてパラメタの配列が不正です",
	'InvalidParameterException:UnrecognisedHttpMethod' => "APIメソッド '%2$s' を呼び出すための httpメソッド %1$s が認識されませんでした",
	'SecurityException:AuthTokenExpired' => "認証トークンが欠落してるか、正しくないか、期限が切れています。",
	'SecurityException:InvalidPostHash' => "POST データハッシュが不正です - %s のはずですが %s になっています。",
	'SecurityException:DupePacket' => "パケット・シグネイチャはすでに見ました。",
	'SecurityException:InvalidAPIKey' => "API Key が不正あるいは欠如しています。",
	'NotImplementedException:CallMethodNotImplemented' => "呼び出しメソッド '%s' は現在サポートされていません。",
	'CallException:InvalidCallMethod' => "%s の呼び出しは '%s' を使用してください。",

	'system.api.list' => "このシステムでの利用可能な全APIコール一覧。",
	'auth.gettoken' => "このAPIコールはユーザ認証トークンをユーザに渡します。このトークンは今後のAPIコールの時に使用されます。 パラメータ auth_token として渡してください。",
);

==> elgg-1.10.1.zip: elgg-1.10.1/mod/web_services/languages/ja.php <==
<?php
return array(
	'APIException:ApiResultUnknown' => "API Result は不明な型です。このようなことは起きないはずなのですが。。。",
	'APIException:MissingParameterInMethod' => "メソッド「 %2$s 」のパラメタ「 %1$s 」が欠落しています",
	'APIException:ParameterNotArray' => "%s は、配列ではないようです。",
	'APIException:UnrecognisedTypeCast' => "メソッド「 %3$s 」の変数「 %2$s 」のキャスト %1$s の型がわかりません。",
	'APIException:InvalidParameter' => "メソッド「 %2$s 」のパラメタ「 %1$s 」が不適切な値でした。",
	'APIException:FunctionParseError' => "%s(%s) にはパース・エラーが１つあります。",
	'APIException:FunctionNoReturn' => "%s(%s) は値を返しませんでした。",
	'APIException:APIAuthenticationFailed' => "メソッドの呼び出しは API Aithentication に失敗しました。",
	'APIException:UserAuthenticationFailed' => "メソッドの呼び出しは User Authentication に失敗しました。",
	'APIException:MethodCallNotImplemented' => "メソッドの呼び出し '%s' は、実装されていません。",
	'APIException:FunctionDoesNotExist' => "メソッド '%s' の関数は呼び出し不可能です。",
	'APIException:AlgorithmNotSupported' => "アルゴリズム '%s' はサポートされていないか、利用不可となっています。",
	'APIException:NotGetOrPost' => "リクエストの手段は GET もしくは、 POST でないといけません。",
	'APIException:MissingAPIKey' => "API key がありません",
	'APIException:BadAPIKey' => "API key が間違っています",
	'APIException:MissingHmac' => "X-Elgg-hmac ヘッダがありません",
	'APIException:MissingHmacAlgo' => "X-Elgg-hmac-algo ヘッダがありません",
	'APIException:MissingTime' => "X-Elgg-time ヘッダがありません",
	'APIException:MissingNonce' => "X-Elgg-nonce ヘッダがありません",
	'APIException:TemporalDrift' => "X-Elgg-time があまりにも過去か未来過ぎます。エポック取得に失敗しました",
	'APIException:NoQueryString' => "クエリ文字列にデータがありません",
	'APIException:MissingPOSTHash' => "X-Elgg-posthash ヘッダがありません",
	'APIException:MissingPOSTAlgo' => "X-Elgg-posthash_algo ヘッダがありません",
	'APIException:MissingContentType' => "投稿データのコンテント型がありません",
	'SecurityException:APIAccessDenied' => "申し訳ありません。API へのアクセスは管理者によって使用不可に設定されています。",
	'SecurityException:NoAuthMethods' => "このAPIリクエストの認証を行うにあたって、担当するメソッドが見つかりませんでした。",
	'SecurityException:authenticationfailed' => "ユーザは認証できませんでした。",
	'InvalidParameterException:APIMethodOrFunctionNotSet' => "expose_method() において、メソッドあるいは関数が設定されていません",
	'InvalidParameterException:APIParametersArrayStructure' => "メソッド '%s' の呼び出しにおいてパラメタの配列が不正です",
	'InvalidParameterException:UnrecognisedHttpMethod' => "APIメソッド「 %2$s 」を呼び出すための httpメソッド %1$s が認識されませんでした",
	'SecurityException:AuthTokenExpired' => "認証トークンが欠落してるか、正しくないか、期限が切れています。",
	'SecurityException:InvalidPostHash' => "POST データハッシュが不正です - %s のはずですが %s になっています。",
	'SecurityException:DupePacket' => "パケット・シグネイチャはすでに見ました。",
	'SecurityException:InvalidAPIKey' => "API Key が不正あるいは欠如しています。",
	'NotImplementedException:CallMethodNotImplemented' => "呼び出しメソッド '%s' は現在サポートされていません。",
	'CallException:InvalidCallMethod' => "%s の呼び出しは '%s' を使用してください。",

	'system.api.list' => "このシステムでの利用可能な全APIコール一覧。",
	'auth.gettoken' => "このAPIコールはユーザ認証トークンをユーザに渡します。このトークンは今後のAPIコールの時に使用されます。 パラメータ auth_token として渡してください。",
);
